<?php

namespace Litecms\PackageSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\PackageSetting\Http\Requests\PackageSettingRequest;
use Litecms\PackageSetting\Interfaces\PackageSettingRepositoryInterface;
use Litecms\PackageSetting\Models\PackageSetting;

/**
 * Resource controller class for package_setting.
 */
class PackageSettingResourceController extends BaseController
{

    /**
     * Initialize package_setting resource controller.
     *
     * @param type PackageSettingRepositoryInterface $package_setting
     *
     * @return null
     */
    public function __construct(PackageSettingRepositoryInterface $package_setting)
    {
        parent::__construct();
        $this->repository = $package_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\PackageSetting\Repositories\Criteria\PackageSettingResourceCriteria::class);
    }

    /**
     * Display a list of package_setting.
     *
     * @return Response
     */
    public function index(PackageSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\PackageSetting\Repositories\Presenter\PackageSettingPresenter::class)
                ->$function();
        }

        $package_settings = $this->repository->paginate();

        return $this->response->title(trans('package_setting::package_setting.names'))
            ->view('package_setting::package_setting.index', true)
            ->data(compact('package_settings'))
            ->output();
    }

    /**
     * Display package_setting.
     *
     * @param Request $request
     * @param Model   $package_setting
     *
     * @return Response
     */
    public function show(PackageSettingRequest $request, PackageSetting $package_setting)
    {

        if ($package_setting->exists) {
            $view = 'package_setting::package_setting.show';
        } else {
            $view = 'package_setting::package_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('package_setting::package_setting.name'))
            ->data(compact('package_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new package_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PackageSettingRequest $request)
    {

        $package_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('package_setting::package_setting.name')) 
            ->view('package_setting::package_setting.create', true) 
            ->data(compact('package_setting'))
            ->output();
    }

    /**
     * Create new package_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PackageSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $package_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('package_setting::package_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('package_setting/package_setting/' . $package_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/package_setting/package_setting'))
                ->redirect();
        }

    }

    /**
     * Show package_setting for editing.
     *
     * @param Request $request
     * @param Model   $package_setting
     *
     * @return Response
     */
    public function edit(PackageSettingRequest $request, PackageSetting $package_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('package_setting::package_setting.name'))
            ->view('package_setting::package_setting.edit', true)
            ->data(compact('package_setting'))
            ->output();
    }

    /**
     * Update the package_setting.
     *
     * @param Request $request
     * @param Model   $package_setting
     *
     * @return Response
     */
    public function update(PackageSettingRequest $request, PackageSetting $package_setting)
    {
        try {
            $attributes = $request->all();

            $package_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('package_setting::package_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('package_setting/package_setting/' . $package_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('package_setting/package_setting/' . $package_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the package_setting.
     *
     * @param Model   $package_setting
     *
     * @return Response
     */
    public function destroy(PackageSettingRequest $request, PackageSetting $package_setting)
    {
        try {

            $package_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('package_setting::package_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('package_setting/package_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('package_setting/package_setting/' . $package_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple package_setting.
     *
     * @param Model   $package_setting
     *
     * @return Response
     */
    public function delete(PackageSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('package_setting::package_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('package_setting/package_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/package_setting/package_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted package_settings.
     *
     * @param Model   $package_setting
     *
     * @return Response
     */
    public function restore(PackageSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('package_setting::package_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/package_setting/package_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/package_setting/package_setting/'))
                ->redirect();
        }

    }

}
